@@ -29,6 +29,7 @@ const (
 
 	// Command specific flags.
 	dockerFileFlag        = "dockerfile"
+	dockerFileContextFlag = "build-context"
 	imageTagFlag          = "tag"
 	resourceTagsFlag      = "resource-tags"
 	stackOutputDirFlag    = "output-dir"
@@ -81,6 +82,8 @@ const (
 	entrypointFlag      = "entrypoint"
 	taskDefaultFlag     = "default"
 	generateCommandFlag = "generate-cmd"
+	osFlag              = "platform-os"
+	archFlag            = "platform-arch"
 
 	vpcIDFlag          = "import-vpc-id"
 	publicSubnetsFlag  = "import-public-subnets"
@@ -138,6 +141,8 @@ var (
 	imageFlagDescription = fmt.Sprintf(`The location of an existing Docker image.
 Mutually exclusive with -%s, --%s.`, dockerFileFlagShort, dockerFileFlag)
 	dockerFileFlagDescription = fmt.Sprintf(`Path to the Dockerfile.
+Mutually exclusive with -%s, --%s.`, imageFlagShort, imageFlag)
+	dockerFileContextFlagDescription = fmt.Sprintf(`Path to the Docker build context.
 Mutually exclusive with -%s, --%s.`, imageFlagShort, imageFlag)
 	storageTypeFlagDescription = fmt.Sprintf(`Type of storage to add. Must be one of:
 %s.`, strings.Join(template.QuoteSliceFunc(storageTypes), ", "))
@@ -162,6 +167,8 @@ Cannot be specified with '%s' or '%s'.`, appFlag, envFlag)
 Cannot be specified with '%s', '%s' or '%s'.`, taskDefaultFlag, subnetsFlag, securityGroupsFlag)
 	taskAppFlagDescription = fmt.Sprintf(`Optional. Name of the application.
 Cannot be specified with '%s', '%s' or '%s'.`, taskDefaultFlag, subnetsFlag, securityGroupsFlag)
+	osFlagDescription   = fmt.Sprintf(`Optional. Operating system of the task. Must be specified along with '%s'.`, archFlag)
+	archFlagDescription = fmt.Sprintf(`Optional. Architecture of the task. Must be specified along with '%s'.`, osFlag)
 
 	secretNameFlagDescription = fmt.Sprintf(`The name of the secret.
 Mutually exclusive with the --%s flag.`, inputFilePathFlag)
