@@ -7,6 +7,8 @@ import (
 	"encoding"
 	"io"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
+
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerfile"
 
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
@@ -229,12 +231,8 @@ type wsFileDeleter interface {
 	DeleteWorkspaceFile() error
 }
 
-type svcManifestReader interface {
-	ReadServiceManifest(svcName string) ([]byte, error)
-}
-
-type jobManifestReader interface {
-	ReadJobManifest(jobName string) ([]byte, error)
+type manifestReader interface {
+	ReadWorkloadManifest(name string) (workspace.WorkloadManifest, error)
 }
 
 type copilotDirGetter interface {
@@ -250,13 +248,13 @@ type wsPipelineWriter interface {
 	WritePipelineManifest(marshaler encoding.BinaryMarshaler) (string, error)
 }
 
-type wsServiceLister interface {
-	ServiceNames() ([]string, error)
+type serviceLister interface {
+	ListServices() ([]string, error)
 }
 
 type wsSvcReader interface {
-	wsServiceLister
-	svcManifestReader
+	serviceLister
+	manifestReader
 }
 
 type wsSvcDirReader interface {
@@ -264,17 +262,17 @@ type wsSvcDirReader interface {
 	copilotDirGetter
 }
 
-type wsJobLister interface {
-	JobNames() ([]string, error)
+type jobLister interface {
+	ListJobs() ([]string, error)
 }
 
 type wsJobReader interface {
-	jobManifestReader
-	wsJobLister
+	manifestReader
+	jobLister
 }
 
-type wsWlReader interface {
-	WorkloadNames() ([]string, error)
+type wlLister interface {
+	ListWorkloads() ([]string, error)
 }
 
 type wsJobDirReader interface {
@@ -286,14 +284,14 @@ type wsWlDirReader interface {
 	wsJobReader
 	wsSvcReader
 	copilotDirGetter
-	wsWlReader
+	wlLister
 	ListDockerfiles() ([]string, error)
 	Summary() (*workspace.Summary, error)
 }
 
 type wsPipelineReader interface {
 	wsPipelineManifestReader
-	WorkloadNames() ([]string, error)
+	wlLister
 }
 
 type wsAppManager interface {
@@ -303,7 +301,8 @@ type wsAppManager interface {
 
 type wsAddonManager interface {
 	WriteAddon(f encoding.BinaryMarshaler, svc, name string) (string, error)
-	wsWlReader
+	manifestReader
+	wlLister
 }
 
 type artifactUploader interface {
@@ -525,6 +524,10 @@ type ec2Client interface {
 	HasDNSSupport(vpcID string) (bool, error)
 }
 
+type vpcSubnetLister interface {
+	ListVPCSubnets(vpcID string) (*ec2.VPCSubnets, error)
+}
+
 type serviceResumer interface {
 	ResumeService(string) error
 }
@@ -596,7 +599,7 @@ type runningTaskSelector interface {
 
 type dockerEngine interface {
 	CheckDockerEngineRunning() error
-	RedirectPlatform(string) (*string, error)
+	GetPlatform() (string, string, error)
 }
 
 type codestar interface {
@@ -623,3 +626,7 @@ type timeoutError interface {
 	error
 	Timeout() bool
 }
+
+type interpolator interface {
+	Interpolate(s string) (string, error)
+}
