@@ -9,6 +9,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/describe"
+
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
@@ -18,7 +20,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
 
 	"github.com/aws/aws-sdk-go/aws"
-	addon "github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/addon"
 	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
@@ -39,6 +41,10 @@ type deploySvcMocks struct {
 	mockServiceDeployer    *mocks.MockserviceDeployer
 	mockSpinner            *mocks.Mockprogress
 	mockServiceUpdater     *mocks.MockserviceUpdater
+	mockInterpolator       *mocks.Mockinterpolator
+	mockDeployStore        *mocks.MockdeployedEnvironmentLister
+	mockEnvDescriber       *mocks.MockenvDescriber
+	mockSubnetLister       *mocks.MockvpcSubnetLister
 }
 
 func TestSvcDeployOpts_Validate(t *testing.T) {
@@ -62,7 +68,7 @@ func TestSvcDeployOpts_Validate(t *testing.T) {
 			inAppName: "phonetool",
 			inSvcName: "frontend",
 			mockWs: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ServiceNames().Return(nil, errors.New("some error"))
+				m.EXPECT().ListServices().Return(nil, errors.New("some error"))
 			},
 			mockStore: func(m *mocks.Mockstore) {},
 
@@ -72,7 +78,7 @@ func TestSvcDeployOpts_Validate(t *testing.T) {
 			inAppName: "phonetool",
 			inSvcName: "frontend",
 			mockWs: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ServiceNames().Return([]string{}, nil)
+				m.EXPECT().ListServices().Return([]string{}, nil)
 			},
 			mockStore: func(m *mocks.Mockstore) {},
 
@@ -94,7 +100,7 @@ func TestSvcDeployOpts_Validate(t *testing.T) {
 			inSvcName: "frontend",
 			inEnvName: "test",
 			mockWs: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ServiceNames().Return([]string{"frontend"}, nil)
+				m.EXPECT().ListServices().Return([]string{"frontend"}, nil)
 			},
 			mockStore: func(m *mocks.Mockstore) {
 				m.EXPECT().GetEnvironment("phonetool", "test").
@@ -270,16 +276,27 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(nil, mockError),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(nil, mockError),
 				)
 			},
 			wantErr: fmt.Errorf("read service %s manifest file: %w", "serviceA", mockError),
 		},
+		"should return error if interpolation fail": {
+			inputSvc: "serviceA",
+			setupMocks: func(m deploySvcMocks) {
+				gomock.InOrder(
+					m.mockWs.EXPECT().ReadWorkloadManifest(gomock.Any()).Return(mockManifest, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return("", mockError),
+				)
+			},
+			wantErr: fmt.Errorf("interpolate environment variables for serviceA manifest: %w", mockError),
+		},
 		"should return error if workspace methods fail": {
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest(gomock.Any()).Return(mockManifest, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest(gomock.Any()).Return(mockManifest, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("", mockError),
 				)
 			},
@@ -289,16 +306,18 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifestWithBadPlatform, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifestWithBadPlatform, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifestWithBadPlatform)).Return(string(mockManifestWithBadPlatform), nil),
 				)
 			},
-			wantErr: fmt.Errorf("unmarshal service serviceA manifest: unmarshal to load balanced web service: validate platform: platform %s is invalid; the valid platform is: %s", "linus/abc123", "linux/amd64"),
+			wantErr: errors.New("validate manifest against environment : validate \"platform\": platform 'linus/abc123' is invalid; valid platforms are: linux/amd64, linux/x86_64, linux/arm, linux/arm64, windows/amd64 and windows/x86_64"),
 		},
 		"success with valid platform": {
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifestWithGoodPlatform, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifestWithGoodPlatform, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifestWithGoodPlatform)).Return(string(mockManifestWithGoodPlatform), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
@@ -313,7 +332,8 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockMftNoBuild, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftNoBuild, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockMftNoBuild)).Return(string(mockMftNoBuild), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Times(0),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), gomock.Any()).Times(0),
 				)
@@ -323,7 +343,8 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifest, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifest, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), gomock.Any()).Return("", mockError),
 				)
@@ -334,7 +355,8 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockManifest, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockManifest, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockManifest)).Return(string(mockManifest), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
@@ -348,7 +370,8 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockMftBuildString, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftBuildString, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockMftBuildString)).Return(string(mockMftBuildString), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
@@ -362,7 +385,8 @@ image:
 			inputSvc: "serviceA",
 			setupMocks: func(m deploySvcMocks) {
 				gomock.InOrder(
-					m.mockWs.EXPECT().ReadServiceManifest("serviceA").Return(mockMftNoContext, nil),
+					m.mockWs.EXPECT().ReadWorkloadManifest("serviceA").Return(mockMftNoContext, nil),
+					m.mockInterpolator.EXPECT().Interpolate(string(mockMftNoContext)).Return(string(mockMftNoContext), nil),
 					m.mockWs.EXPECT().CopilotDirPath().Return("/ws/root/copilot", nil),
 					m.mockimageBuilderPusher.EXPECT().BuildAndPush(gomock.Any(), &dockerengine.BuildArguments{
 						Dockerfile: filepath.Join("/ws", "root", "path", "to", "Dockerfile"),
@@ -381,9 +405,11 @@ image:
 
 			mockWorkspace := mocks.NewMockwsSvcDirReader(ctrl)
 			mockimageBuilderPusher := mocks.NewMockimageBuilderPusher(ctrl)
+			mockInterpolator := mocks.NewMockinterpolator(ctrl)
 			mocks := deploySvcMocks{
 				mockWs:                 mockWorkspace,
 				mockimageBuilderPusher: mockimageBuilderPusher,
+				mockInterpolator:       mockInterpolator,
 			}
 			test.setupMocks(mocks)
 			opts := deploySvcOpts{
@@ -393,6 +419,9 @@ image:
 				unmarshal:          manifest.UnmarshalWorkload,
 				imageBuilderPusher: mockimageBuilderPusher,
 				ws:                 mockWorkspace,
+				newInterpolator: func(app, env string) interpolator {
+					return mockInterpolator
+				},
 			}
 
 			gotErr := opts.configureContainerImage()
@@ -570,6 +599,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 	)
 	tests := map[string]struct {
 		inAliases      manifest.Alias
+		inNLB          manifest.NetworkLoadBalancerConfiguration
 		inApp          *config.Application
 		inEnvironment  *config.Environment
 		inBuildRequire bool
@@ -581,10 +611,62 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 	}{
 		"fail to read service manifest": {
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return(nil, mockError)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return(nil, mockError)
 			},
 			wantErr: fmt.Errorf("read service %s manifest file: %w", mockSvcName, mockError),
 		},
+		"fail to interpolate manifest": {
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", mockError)
+			},
+			wantErr: fmt.Errorf("interpolate environment variables for mockSvc manifest: %w", mockError),
+		},
+		"fail to describe environment": {
+			inBuildRequire: false,
+			inNLB: manifest.NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/udp"),
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvDescriber.EXPECT().Describe().Return(nil, errors.New("some error"))
+			},
+			wantErr: fmt.Errorf("describe environment mockEnv: some error"),
+		},
+		"fail to list subnets": {
+			inBuildRequire: false,
+			inNLB: manifest.NetworkLoadBalancerConfiguration{
+				Port: aws.String("443/udp"),
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvDescriber.EXPECT().Describe().Return(&describe.EnvDescription{
+					EnvironmentVPC: describe.EnvironmentVPC{
+						ID: "mockVPCID",
+					},
+				}, nil)
+				m.mockSubnetLister.EXPECT().ListVPCSubnets("mockVPCID").Return(nil, errors.New("some error"))
+			},
+			wantErr: fmt.Errorf("list subnets of vpc mockVPCID in environment mockEnv: some error"),
+		},
 		"fail to get app resources": {
 			inBuildRequire: true,
 			inEnvironment: &config.Environment{
@@ -595,7 +677,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Name: mockAppName,
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
 					Name: mockAppName,
 				}, "us-west-2").Return(nil, mockError)
@@ -603,6 +686,22 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("get application %s resources from region us-west-2: %w", mockAppName, mockError),
 		},
+		"alias used while app is not associated with a domain": {
+			inAliases: manifest.Alias{String: aws.String("mockAlias")},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+			},
+			wantErr: errors.New("alias specified when application is not associated with a domain"),
+		},
 		"cannot to find ECR repo": {
 			inBuildRequire: true,
 			inEnvironment: &config.Environment{
@@ -614,7 +713,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				AccountID: "1234567890",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppResourcesGetter.EXPECT().GetAppResourcesByRegion(&config.Application{
 					Name:      mockAppName,
 					AccountID: "1234567890",
@@ -636,7 +736,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("", mockError)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 			},
@@ -653,7 +754,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v0.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 			},
@@ -670,10 +772,10 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-
 			},
 			wantErr: fmt.Errorf(`alias "v1.v2.mockDomain" is not supported in hosted zones managed by Copilot`),
 		},
@@ -687,7 +789,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(errors.New("some error"))
 			},
@@ -703,7 +806,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(cloudformation.NewMockErrChangeSetEmpty())
 			},
@@ -720,7 +824,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(cloudformation.NewMockErrChangeSetEmpty())
@@ -741,7 +846,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).
 					Return(cloudformation.NewMockErrChangeSetEmpty())
@@ -771,10 +877,12 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(nil)
+
 			},
 		},
 		"success with force update": {
@@ -788,7 +896,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deploySvcMocks) {
-				m.mockWs.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), gomock.Any()).Return(cloudformation.NewMockErrChangeSetEmpty())
 				m.mockSpinner.EXPECT().Start(fmt.Sprintf(fmtForceUpdateSvcStart, mockSvcName, mockEnvName))
@@ -811,6 +920,9 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				mockServiceDeployer:    mocks.NewMockserviceDeployer(ctrl),
 				mockServiceUpdater:     mocks.NewMockserviceUpdater(ctrl),
 				mockSpinner:            mocks.NewMockprogress(ctrl),
+				mockInterpolator:       mocks.NewMockinterpolator(ctrl),
+				mockEnvDescriber:       mocks.NewMockenvDescriber(ctrl),
+				mockSubnetLister:       mocks.NewMockvpcSubnetLister(ctrl),
 			}
 			tc.mock(m)
 
@@ -830,6 +942,9 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				endpointGetter:    m.mockEndpointGetter,
 				targetApp:         tc.inApp,
 				targetEnvironment: tc.inEnvironment,
+				newInterpolator: func(app, env string) interpolator {
+					return m.mockInterpolator
+				},
 				unmarshal: func(b []byte) (manifest.WorkloadManifest, error) {
 					return &manifest.LoadBalancedWebService{
 						Workload: manifest.Workload{
@@ -847,6 +962,7 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 							RoutingRule: manifest.RoutingRule{
 								Alias: tc.inAliases,
 							},
+							NLBConfig: tc.inNLB,
 						},
 					}, nil
 				},
@@ -854,6 +970,8 @@ func TestSvcDeployOpts_deploySvc(t *testing.T) {
 				svcUpdater:    m.mockServiceUpdater,
 				newSvcUpdater: func(f func(*session.Session) serviceUpdater) {},
 				spinner:       m.mockSpinner,
+				envDescriber:  m.mockEnvDescriber,
+				subnetLister:  m.mockSubnetLister,
 			}
 
 			gotErr := opts.deploySvc(mockAddonsURL)
@@ -874,6 +992,7 @@ type deployRDSvcMocks struct {
 	mockEndpointGetter     *mocks.MockendpointGetter
 	mockIdentity           *mocks.MockidentityService
 	mockUploader           *mocks.MockcustomResourcesUploader
+	mockInterpolator       *mocks.Mockinterpolator
 }
 
 func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
@@ -894,6 +1013,24 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 		wantURLs map[string]string
 		wantErr  error
 	}{
+		"alias used while app is not associated with a domain": {
+			inAlias: "v1.mockDomain",
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deployRDSvcMocks) {
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+
+			},
+
+			wantErr: errors.New("alias specified when application is not associated with a domain"),
+		},
 		"fail to get identity for rd web service": {
 			inAlias: "v1.mockDomain",
 			inEnvironment: &config.Environment{
@@ -905,7 +1042,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{}, errors.New("some error"))
 			},
@@ -923,7 +1061,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -948,7 +1087,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -969,7 +1109,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -990,7 +1131,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -1011,7 +1153,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -1032,7 +1175,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -1060,7 +1204,8 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				Domain: "mockDomain",
 			},
 			mock: func(m *deployRDSvcMocks) {
-				m.mockWorkspace.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockWorkspace.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
 				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
 				m.mockIdentity.EXPECT().Get().Return(identity.Caller{
@@ -1095,6 +1240,7 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				mockEndpointGetter:     mocks.NewMockendpointGetter(ctrl),
 				mockIdentity:           mocks.NewMockidentityService(ctrl),
 				mockUploader:           mocks.NewMockcustomResourcesUploader(ctrl),
+				mockInterpolator:       mocks.NewMockinterpolator(ctrl),
 			}
 			tc.mock(m)
 
@@ -1109,6 +1255,9 @@ func TestSvcDeployOpts_rdWebServiceStackConfiguration(t *testing.T) {
 				newAppVersionGetter: func(s string) (versionGetter, error) {
 					return m.mockAppVersionGetter, nil
 				},
+				newInterpolator: func(app, env string) interpolator {
+					return m.mockInterpolator
+				},
 				newSvcUpdater:     func(f func(*session.Session) serviceUpdater) {},
 				endpointGetter:    m.mockEndpointGetter,
 				identity:          m.mockIdentity,
@@ -1166,23 +1315,15 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 		inEnvironment  *config.Environment
 		inBuildRequire bool
 
-		mockWorkspace          func(m *mocks.MockwsSvcDirReader)
-		mockAppResourcesGetter func(m *mocks.MockappResourcesGetter)
-		mockAppVersionGetter   func(m *mocks.MockversionGetter)
-		mockEndpointGetter     func(m *mocks.MockendpointGetter)
-		mockDeployStore        func(m *mocks.MockdeployedEnvironmentLister)
+		mock func(m *deploySvcMocks)
 
 		wantErr error
 	}{
 		"fail to read service manifest": {
-			mockWorkspace: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ReadServiceManifest(mockSvcName).Return(nil, mockError)
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return(nil, mockError)
 			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {},
-			mockAppVersionGetter:   func(m *mocks.MockversionGetter) {},
-			mockEndpointGetter:     func(m *mocks.MockendpointGetter) {},
-			mockDeployStore:        func(m *mocks.MockdeployedEnvironmentLister) {},
-			wantErr:                fmt.Errorf("read service %s manifest file: %w", mockSvcName, mockError),
+			wantErr: fmt.Errorf("read service %s manifest file: %w", mockSvcName, mockError),
 		},
 		"fail to get deployed topics": {
 			inEnvironment: &config.Environment{
@@ -1193,16 +1334,11 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 				Name:   mockAppName,
 				Domain: "mockDomain",
 			},
-			mockWorkspace: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
-			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {},
-			mockAppVersionGetter:   func(m *mocks.MockversionGetter) {},
-			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
-				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-			},
-			mockDeployStore: func(m *mocks.MockdeployedEnvironmentLister) {
-				m.EXPECT().ListSNSTopics(mockAppName, mockEnvName).Return(nil, mockError)
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockDeployStore.EXPECT().ListSNSTopics(mockAppName, mockEnvName).Return(nil, mockError)
 			},
 			wantErr: fmt.Errorf("get SNS topics for app mockApp and environment mockEnv: %w", mockError),
 		},
@@ -1215,16 +1351,11 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 				Name:   mockAppName,
 				Domain: "mockDomain",
 			},
-			mockWorkspace: func(m *mocks.MockwsSvcDirReader) {
-				m.EXPECT().ReadServiceManifest(mockSvcName).Return([]byte{}, nil)
-			},
-			mockAppResourcesGetter: func(m *mocks.MockappResourcesGetter) {},
-			mockAppVersionGetter:   func(m *mocks.MockversionGetter) {},
-			mockEndpointGetter: func(m *mocks.MockendpointGetter) {
-				m.EXPECT().ServiceDiscoveryEndpoint().Return("mockEnv.mockApp.local", nil)
-			},
-			mockDeployStore: func(m *mocks.MockdeployedEnvironmentLister) {
-				m.EXPECT().ListSNSTopics(mockAppName, mockEnvName).Return([]deploy.Topic{
+			mock: func(m *deploySvcMocks) {
+				m.mockWs.EXPECT().ReadWorkloadManifest(mockSvcName).Return([]byte{}, nil)
+				m.mockInterpolator.EXPECT().Interpolate("").Return("", nil)
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockEnv.mockApp.local", nil)
+				m.mockDeployStore.EXPECT().ListSNSTopics(mockAppName, mockEnvName).Return([]deploy.Topic{
 					*topic,
 				}, nil)
 			},
@@ -1235,17 +1366,13 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			ctrl := gomock.NewController(t)
 			defer ctrl.Finish()
-
-			mockWorkspace := mocks.NewMockwsSvcDirReader(ctrl)
-			mockAppResourcesGetter := mocks.NewMockappResourcesGetter(ctrl)
-			mockAppVersionGetter := mocks.NewMockversionGetter(ctrl)
-			mockEndpointGetter := mocks.NewMockendpointGetter(ctrl)
-			mockDeployStore := mocks.NewMockdeployedEnvironmentLister(ctrl)
-			tc.mockWorkspace(mockWorkspace)
-			tc.mockAppResourcesGetter(mockAppResourcesGetter)
-			tc.mockAppVersionGetter(mockAppVersionGetter)
-			tc.mockEndpointGetter(mockEndpointGetter)
-			tc.mockDeployStore(mockDeployStore)
+			m := &deploySvcMocks{
+				mockWs:             mocks.NewMockwsSvcDirReader(ctrl),
+				mockEndpointGetter: mocks.NewMockendpointGetter(ctrl),
+				mockDeployStore:    mocks.NewMockdeployedEnvironmentLister(ctrl),
+				mockInterpolator:   mocks.NewMockinterpolator(ctrl),
+			}
+			tc.mock(m)
 
 			opts := deploySvcOpts{
 				deployWkldVars: deployWkldVars{
@@ -1253,17 +1380,16 @@ func TestSvcDeployOpts_stackConfiguration_worker(t *testing.T) {
 					appName: mockAppName,
 					envName: mockEnvName,
 				},
-				ws:            mockWorkspace,
-				buildRequired: tc.inBuildRequire,
-				appCFN:        mockAppResourcesGetter,
-				newAppVersionGetter: func(s string) (versionGetter, error) {
-					return mockAppVersionGetter, nil
-				},
+				ws:                m.mockWs,
+				buildRequired:     tc.inBuildRequire,
 				newSvcUpdater:     func(f func(*session.Session) serviceUpdater) {},
-				endpointGetter:    mockEndpointGetter,
-				snsTopicGetter:    mockDeployStore,
+				endpointGetter:    m.mockEndpointGetter,
+				snsTopicGetter:    m.mockDeployStore,
 				targetApp:         tc.inApp,
 				targetEnvironment: tc.inEnvironment,
+				newInterpolator: func(app, env string) interpolator {
+					return m.mockInterpolator
+				},
 				unmarshal: func(b []byte) (manifest.WorkloadManifest, error) {
 					return &manifest.WorkerService{
 						Workload: manifest.Workload{
