@@ -50,8 +50,9 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 
 		inName string
 
-		inImage          string
-		inDockerfilePath string
+		inImage                 string
+		inDockerfilePath        string
+		inDockerfileContextPath string
 
 		inTaskRole string
 
@@ -64,6 +65,8 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 		inSecrets    map[string]string
 		inCommand    string
 		inEntryPoint string
+		inOS         string
+		inArch       string
 
 		inDefault               bool
 		inGenerateCommandTarget string
@@ -137,6 +140,32 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 			},
 			wantedError: nil,
 		},
+		"invalid with os but not arch": {
+			basicOpts:   defaultOpts,
+			inOS:        "WINDOWS_SERVER_2019_CORE",
+			wantedError: errors.New("must specify either both `--platform-os` and `--platform-arch` or neither"),
+		},
+		"invalid with arch but not os": {
+			basicOpts:   defaultOpts,
+			inArch:      "X86_64",
+			wantedError: errors.New("must specify either both `--platform-os` and `--platform-arch` or neither"),
+		},
+		"invalid platform": {
+			basicOpts:   defaultOpts,
+			inOS:        "OStrich",
+			inArch:      "MAD666",
+			wantedError: errors.New("platform OSTRICH/MAD666 is invalid; valid platforms are: WINDOWS_SERVER_2019_CORE/X86_64, WINDOWS_SERVER_2019_FULL/X86_64, LINUX/X86_64 and LINUX/ARM64"),
+		},
+		"uppercase any lowercase before validating": {
+			basicOpts: basicOpts{
+				inCount:  1,
+				inCPU:    1024,
+				inMemory: 2048,
+			},
+			inOS:        "windows_server_2019_core",
+			inArch:      "x86_64",
+			wantedError: nil,
+		},
 		"invalid number of tasks": {
 			basicOpts: basicOpts{
 				inCount:  -1,
@@ -153,6 +182,16 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 			},
 			wantedError: errCPUNotPositive,
 		},
+		"invalid number of CPU units for Windows task": {
+			basicOpts: basicOpts{
+				inCount:  1,
+				inCPU:    260,
+				inMemory: 512,
+			},
+			inOS:        "WINDOWS_SERVER_2019_CORE",
+			inArch:      "X86_64",
+			wantedError: errors.New("CPU is 260, but it must be at least 1024 for a Windows-based task"),
+		},
 		"invalid memory": {
 			basicOpts: basicOpts{
 				inCount:  1,
@@ -161,6 +200,24 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 			},
 			wantedError: errMemNotPositive,
 		},
+		"invalid memory for Windows task": {
+			basicOpts: basicOpts{
+				inCount:  1,
+				inCPU:    1024,
+				inMemory: 2000,
+			},
+			inOS:        "WINDOWS_SERVER_2019_CORE",
+			inArch:      "X86_64",
+			wantedError: errors.New("memory is 2000, but it must be at least 2048 for a Windows-based task"),
+		},
+		"both build context and image name specified": {
+			basicOpts: defaultOpts,
+
+			inImage:                 "113459295.dkr.ecr.ap-northeast-1.amazonaws.com/my-app",
+			inDockerfileContextPath: "../../other",
+
+			wantedError: errors.New("cannot specify both `--image` and `--build-context`"),
+		},
 		"both dockerfile and image name specified": {
 			basicOpts: defaultOpts,
 
@@ -175,7 +232,14 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 			inDockerfilePath: "world/hello/Dockerfile",
 			isDockerfileSet:  true,
 
-			wantedError: errors.New("open world/hello/Dockerfile: file does not exist"),
+			wantedError: errors.New("invalid `--dockerfile` path: open world/hello/Dockerfile: file does not exist"),
+		},
+		"invalid build context path": {
+			basicOpts: defaultOpts,
+
+			inDockerfileContextPath: "world/hello/Dockerfile",
+
+			wantedError: errors.New("invalid `--build-context` path: open world/hello/Dockerfile: file does not exist"),
 		},
 		"specified app exists": {
 			basicOpts: defaultOpts,
@@ -338,12 +402,15 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 					subnets:                     tc.inSubnets,
 					securityGroups:              tc.inSecurityGroups,
 					dockerfilePath:              tc.inDockerfilePath,
+					dockerfileContextPath:       tc.inDockerfileContextPath,
 					envVars:                     tc.inEnvVars,
 					secrets:                     tc.inSecrets,
 					command:                     tc.inCommand,
 					entrypoint:                  tc.inEntryPoint,
 					useDefaultSubnetsAndCluster: tc.inDefault,
 					generateCommandTarget:       tc.inGenerateCommandTarget,
+					os:                          tc.inOS,
+					arch:                        tc.inArch,
 				},
 				isDockerfileSet: tc.isDockerfileSet,
 				nFlag:           2,
@@ -361,7 +428,7 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 
 			err := opts.Validate()
 			if tc.wantedError != nil {
-				require.EqualError(t, tc.wantedError, err.Error())
+				require.EqualError(t, err, tc.wantedError.Error())
 			} else {
 				require.NoError(t, err)
 			}
@@ -651,6 +718,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 		inSecrets    map[string]string
 		inImage      string
 		inTag        string
+		inDockerCtx  string
 		inFollow     bool
 		inCommand    string
 		inEntryPoint string
@@ -774,6 +842,23 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				mockHasDefaultCluster(m)
 			},
 		},
+		"should use provided docker build context instead of dockerfile path": {
+			inDockerCtx: "../../other",
+			setupMocks: func(m runTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
+				m.store.EXPECT().GetEnvironment(gomock.Any(), gomock.Any()).AnyTimes()
+				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).AnyTimes()
+				m.repository.EXPECT().BuildAndPush(gomock.Any(), gomock.Eq(
+					&dockerengine.BuildArguments{
+						Context: "../../other",
+						Tags:    []string{imageTagLatest},
+					}),
+				)
+				m.repository.EXPECT().URI().AnyTimes()
+				m.runner.EXPECT().Run().AnyTimes()
+				mockHasDefaultCluster(m)
+			},
+		},
 		"update image to task resource if image is not provided": {
 			inSecrets: map[string]string{
 				"quiet": "shh",
@@ -886,8 +971,10 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				runTaskVars: runTaskVars{
 					groupName: inGroupName,
 
-					image:      tc.inImage,
-					imageTag:   tc.inTag,
+					image:                 tc.inImage,
+					imageTag:              tc.inTag,
+					dockerfileContextPath: tc.inDockerCtx,
+
 					env:        tc.inEnv,
 					follow:     tc.inFollow,
 					secrets:    tc.inSecrets,
