@@ -79,10 +79,6 @@ func (e *EnvStackConfig) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
-	_, enableLongARN, err := s3.ParseURL(e.in.CustomResourcesURLs[template.EnableLongARNsFileName])
-	if err != nil {
-		return "", err
-	}
 	_, customDomain, err := s3.ParseURL(e.in.CustomResourcesURLs[template.CustomDomainFileName])
 	if err != nil {
 		return "", err
@@ -93,16 +89,15 @@ func (e *EnvStackConfig) Template() (string, error) {
 	}
 
 	content, err := e.parser.ParseEnv(&template.EnvOpts{
-		AppName:                   e.in.App.Name,
-		DNSCertValidatorLambda:    dnsCertValidator,
-		DNSDelegationLambda:       dnsDelegation,
-		EnableLongARNFormatLambda: enableLongARN,
-		CustomDomainLambda:        customDomain,
-		ScriptBucketName:          bucket,
-		ImportVPC:                 e.in.ImportVPCConfig,
-		VPCConfig:                 vpcConf,
-		Version:                   e.in.Version,
-		LatestVersion:             deploy.LatestEnvTemplateVersion,
+		AppName:                e.in.App.Name,
+		DNSCertValidatorLambda: dnsCertValidator,
+		DNSDelegationLambda:    dnsDelegation,
+		CustomDomainLambda:     customDomain,
+		ScriptBucketName:       bucket,
+		ImportVPC:              e.in.ImportVPCConfig,
+		VPCConfig:              vpcConf,
+		Version:                e.in.Version,
+		LatestVersion:          deploy.LatestEnvTemplateVersion,
 	}, template.WithFuncs(map[string]interface{}{
 		"inc": template.IncFunc,
 	}))
