@@ -1,3 +1,4 @@
+//go:build integration || localintegration
 // +build integration localintegration
 
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
@@ -8,15 +9,15 @@ package stack_test
 import (
 	"fmt"
 	"io/ioutil"
+	"os"
 	"path/filepath"
 	"regexp"
 	"strings"
 	"testing"
 
-	"gopkg.in/yaml.v3"
-
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/template"
+	"gopkg.in/yaml.v3"
 
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 
@@ -52,29 +53,39 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 			svcParamsPath: "svc-prod.params.json",
 		},
 	}
+	val, exist := os.LookupEnv("TAG")
+	require.NoError(t, os.Setenv("TAG", "cicdtest"))
+	defer func() {
+		if !exist {
+			require.NoError(t, os.Unsetenv("TAG"))
+			return
+		}
+		require.NoError(t, os.Setenv("TAG", val))
+	}()
 	path := filepath.Join("testdata", "workloads", svcManifestPath)
 	manifestBytes, err := ioutil.ReadFile(path)
 	require.NoError(t, err)
 	for name, tc := range testCases {
-		mft, err := manifest.UnmarshalWorkload(manifestBytes)
+		interpolated, err := manifest.NewInterpolator(appName, tc.envName).Interpolate(string(manifestBytes))
+		require.NoError(t, err)
+		mft, err := manifest.UnmarshalWorkload([]byte(interpolated))
 		require.NoError(t, err)
-
 		envMft, err := mft.ApplyEnv(tc.envName)
 		require.NoError(t, err)
 
-		err = mft.Validate()
+		err = envMft.Validate()
 		require.NoError(t, err)
 
 		v, ok := envMft.(*manifest.LoadBalancedWebService)
 		require.True(t, ok)
 
 		svcDiscoveryEndpointName := fmt.Sprintf("%s.%s.local", tc.envName, appName)
-		serializer, err := stack.NewHTTPSLoadBalancedWebService(v, tc.envName, appName, stack.RuntimeConfig{
+
+		serializer, err := stack.NewLoadBalancedWebService(v, tc.envName, appName, stack.RuntimeConfig{
 			ServiceDiscoveryEndpoint: svcDiscoveryEndpointName,
 			AccountID:                "123456789123",
 			Region:                   "us-west-2",
-		})
-
+		}, stack.WithHTTPS())
 		tpl, err := serializer.Template()
 		require.NoError(t, err, "template should render")
 		regExpGUID := regexp.MustCompile(`([a-f\d]{8}-)([a-f\d]{4}-){3}([a-f\d]{12})`) // Matches random guids
@@ -99,6 +110,7 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 			actualString = strings.ReplaceAll(actualString, envControllerZipFile, "mockEnvControllerZipFile")
 			actualString = strings.ReplaceAll(actualString, dynamicDesiredCountZipFile, "mockDynamicDesiredCountZipFile")
 			actualString = strings.ReplaceAll(actualString, rulePriorityZipFile, "mockRulePriorityZipFile")
+
 			actualBytes = []byte(actualString)
 			mActual := make(map[interface{}]interface{})
 			require.NoError(t, yaml.Unmarshal(actualBytes, mActual))
