@@ -9,9 +9,8 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/aws/copilot-cli/internal/pkg/deploy"
-
 	"github.com/aws/copilot-cli/internal/pkg/addon"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
@@ -212,6 +211,7 @@ func TestRequestDrivenWebService_NewRequestDrivenWebServiceWithAlias(t *testing.
 }
 
 func TestRequestDrivenWebService_Template(t *testing.T) {
+	const mockSD = "app.env.svc.local.com"
 	testCases := map[string]struct {
 		inCustomResourceURLs map[string]string
 		inManifest           func(manifest manifest.RequestDrivenWebService) manifest.RequestDrivenWebService
@@ -219,19 +219,32 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 		wantedTemplate       string
 		wantedError          error
 	}{
+		"should throw an error if env controller cannot be parsed": {
+			inManifest: func(mft manifest.RequestDrivenWebService) manifest.RequestDrivenWebService {
+				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&manifest.PrivateSubnetPlacement)
+				return mft
+			},
+			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
+				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
+				mockParser.EXPECT().Read(envControllerPath).Return(nil, errors.New("some error"))
+				c.parser = mockParser
+			},
+			wantedError: fmt.Errorf("read env controller lambda: %w", errors.New("some error")), // TODO
+		},
 		"should throw an error if addons template cannot be parsed": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
 				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
-				addons := mockTemplater{err: errors.New("some error")}
+				addons := mockAddons{tplErr: errors.New("some error")}
 				c.parser = mockParser
 				c.wkld.addons = addons
 			},
 			wantedError: fmt.Errorf("generate addons template for %s: %w", testServiceName, errors.New("some error")), // TODO
 		},
 		"should be able to parse custom resource URLs when alias is enabled": {
-			inManifest: func(manifest manifest.RequestDrivenWebService) manifest.RequestDrivenWebService {
-				manifest.Alias = aws.String("convex.domain.com")
-				return manifest
+			inManifest: func(mft manifest.RequestDrivenWebService) manifest.RequestDrivenWebService {
+				mft.Alias = aws.String("convex.domain.com")
+				mft.Network.VPC.Placement = (*manifest.RequestDrivenWebServicePlacement)(&manifest.PrivateSubnetPlacement)
+				return mft
 			},
 			inCustomResourceURLs: map[string]string{
 				template.AppRunnerCustomDomainLambdaFileName: "https://mockbucket.s3-us-east-1.amazonaws.com/mockURL1",
@@ -239,26 +252,47 @@ func TestRequestDrivenWebService_Template(t *testing.T) {
 			},
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
 				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
-				addons := mockTemplater{err: &addon.ErrAddonsNotFound{}}
+				mockParser.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}}
 				mockBucket, mockCustomDomainLambda := "mockbucket", "mockURL1"
-				mockParser.EXPECT().ParseRequestDrivenWebService(template.ParseRequestDrivenWebServiceInput{
-					Variables:          c.manifest.Variables,
-					Tags:               c.manifest.Tags,
-					EnableHealthCheck:  true,
-					Alias:              aws.String("convex.domain.com"),
-					ScriptBucketName:   &mockBucket,
-					CustomDomainLambda: &mockCustomDomainLambda,
-					AWSSDKLayer:        aws.String("arn:aws:lambda:us-west-2:420165488524:layer:AWSLambda-Node-AWS-SDK:14"),
+				mockParser.EXPECT().ParseRequestDrivenWebService(template.WorkloadOpts{
+					Variables:           c.manifest.Variables,
+					Tags:                c.manifest.Tags,
+					EnableHealthCheck:   true,
+					Alias:               aws.String("convex.domain.com"),
+					ScriptBucketName:    &mockBucket,
+					CustomDomainLambda:  &mockCustomDomainLambda,
+					EnvControllerLambda: "something",
+					Network: template.NetworkOpts{
+						SubnetsType: "PrivateSubnets",
+					},
+					ServiceDiscoveryEndpoint: mockSD,
+					AWSSDKLayer:              aws.String("arn:aws:lambda:us-west-2:420165488524:layer:AWSLambda-Node-AWS-SDK:14"),
 				}).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
 				c.parser = mockParser
 				c.wkld.addons = addons
 			},
 			wantedTemplate: "template",
 		},
+		"should parse template without addons/ directory": {
+			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
+				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}, paramsErr: &addon.ErrAddonsNotFound{}}
+				mockParser.EXPECT().ParseRequestDrivenWebService(template.WorkloadOpts{
+					Variables:                c.manifest.Variables,
+					Tags:                     c.manifest.Tags,
+					ServiceDiscoveryEndpoint: mockSD,
+					EnableHealthCheck:        true,
+				}).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
+				c.parser = mockParser
+				c.addons = addons
+			},
+			wantedTemplate: "template",
+		},
 		"should parse template with addons": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
 				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
-				addons := mockTemplater{
+				addons := mockAddons{
 					tpl: `Resources:
   AdditionalResourcesPolicy:
     Type: AWS::IAM::ManagedPolicy
@@ -280,9 +314,10 @@ Outputs:
   Hello:
     Value: hello`,
 				}
-				mockParser.EXPECT().ParseRequestDrivenWebService(template.ParseRequestDrivenWebServiceInput{
-					Variables: c.manifest.Variables,
-					Tags:      c.manifest.Tags,
+				mockParser.EXPECT().ParseRequestDrivenWebService(template.WorkloadOpts{
+					Variables:                c.manifest.Variables,
+					Tags:                     c.manifest.Tags,
+					ServiceDiscoveryEndpoint: mockSD,
 					NestedStack: &template.WorkloadNestedStackOpts{
 						StackName:       addon.StackName,
 						VariableOutputs: []string{"DDBTableName", "Hello"},
@@ -298,11 +333,12 @@ Outputs:
 		"should return parsing error": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
 				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
-				addons := mockTemplater{err: &addon.ErrAddonsNotFound{}}
-				mockParser.EXPECT().ParseRequestDrivenWebService(template.ParseRequestDrivenWebServiceInput{
-					Variables:         c.manifest.Variables,
-					Tags:              c.manifest.Tags,
-					EnableHealthCheck: true,
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}}
+				mockParser.EXPECT().ParseRequestDrivenWebService(template.WorkloadOpts{
+					Variables:                c.manifest.Variables,
+					Tags:                     c.manifest.Tags,
+					ServiceDiscoveryEndpoint: mockSD,
+					EnableHealthCheck:        true,
 				}).Return(nil, errors.New("parsing error"))
 				c.parser = mockParser
 				c.addons = addons
@@ -319,7 +355,7 @@ Outputs:
 			},
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *RequestDrivenWebService) {
 				mockParser := mocks.NewMockrequestDrivenWebSvcReadParser(ctrl)
-				addons := mockTemplater{err: &addon.ErrAddonsNotFound{}}
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}}
 				c.parser = mockParser
 				c.wkld.addons = addons
 			},
@@ -348,8 +384,9 @@ Outputs:
 								RepoURL:  testImageRepoURL,
 								ImageTag: testImageTag,
 							},
-							AccountID: "0123456789012",
-							Region:    "us-west-2",
+							ServiceDiscoveryEndpoint: mockSD,
+							AccountID:                "0123456789012",
+							Region:                   "us-west-2",
 						},
 					},
 					healthCheckConfig: mft.HealthCheckConfiguration,
