@@ -19,7 +19,7 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-// mockTemplater is declared in lb_web_svc_test.go
+// mockAddons is declared in lb_web_svc_test.go
 const (
 	testJobAppName      = "cuteoverload"
 	testJobEnvName      = "test"
@@ -62,7 +62,7 @@ func TestScheduledJob_Template(t *testing.T) {
 						Timeout: aws.Int(5400),
 						Retries: aws.Int(3),
 					},
-					Network: &template.NetworkOpts{
+					Network: template.NetworkOpts{
 						AssignPublicIP: template.EnablePublicIP,
 						SubnetsType:    template.PublicSubnetsPlacement,
 					},
@@ -70,7 +70,7 @@ func TestScheduledJob_Template(t *testing.T) {
 					Command:             []string{"world"},
 					EnvControllerLambda: "something",
 				})).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
-				addons := mockTemplater{err: &addon.ErrAddonsNotFound{}}
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}, paramsErr: &addon.ErrAddonsNotFound{}}
 				j.parser = m
 				j.wkld.addons = addons
 			},
@@ -87,12 +87,14 @@ func TestScheduledJob_Template(t *testing.T) {
 						SecretOutputs:   []string{"MySecretArn"},
 						PolicyOutputs:   []string{"AdditionalResourcesPolicyArn"},
 					},
+					AddonsExtraParams: `ServiceName: !GetAtt Service.Name
+DiscoveryServiceArn: !GetAtt DiscoveryService.Arn`,
 					ScheduleExpression: "cron(0 0 * * ? *)",
 					StateMachine: &template.StateMachineOpts{
 						Timeout: aws.Int(5400),
 						Retries: aws.Int(3),
 					},
-					Network: &template.NetworkOpts{
+					Network: template.NetworkOpts{
 						AssignPublicIP: template.EnablePublicIP,
 						SubnetsType:    template.PublicSubnetsPlacement,
 					},
@@ -100,7 +102,7 @@ func TestScheduledJob_Template(t *testing.T) {
 					Command:             []string{"world"},
 					EnvControllerLambda: "something",
 				})).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
-				addons := mockTemplater{
+				addons := mockAddons{
 					tpl: `Resources:
   AdditionalResourcesPolicy:
     Type: AWS::IAM::ManagedPolicy
@@ -126,6 +128,8 @@ Outputs:
     Value: !Ref MySecret
   Hello:
     Value: hello`,
+					params: `ServiceName: !GetAtt Service.Name
+DiscoveryServiceArn: !GetAtt DiscoveryService.Arn`,
 				}
 				j.parser = m
 				j.wkld.addons = addons
@@ -135,7 +139,7 @@ Outputs:
 		"error parsing addons": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, j *ScheduledJob) {
 				m := mocks.NewMockscheduledJobReadParser(ctrl)
-				addons := mockTemplater{err: errors.New("some error")}
+				addons := mockAddons{tplErr: errors.New("some error")}
 				j.parser = m
 				j.wkld.addons = addons
 			},
@@ -146,7 +150,7 @@ Outputs:
 				m := mocks.NewMockscheduledJobReadParser(ctrl)
 				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
 				m.EXPECT().ParseScheduledJob(gomock.Any()).Return(nil, errors.New("some error"))
-				addons := mockTemplater{err: &addon.ErrAddonsNotFound{}}
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}}
 				j.parser = m
 				j.wkld.addons = addons
 			},
