@@ -16,6 +16,7 @@ import (
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/endpoints"
+
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 )
@@ -64,15 +65,17 @@ func convertSidecar(s map[string]*manifest.SidecarConfig) ([]*template.SidecarOp
 		}
 		mp := convertSidecarMountPoints(config.MountPoints)
 		sidecars = append(sidecars, &template.SidecarOpts{
-			Name:         aws.String(name),
-			Image:        config.Image,
-			Essential:    config.Essential,
-			Port:         port,
-			Protocol:     protocol,
-			CredsParam:   config.CredsParam,
-			Secrets:      config.Secrets,
-			Variables:    config.Variables,
-			MountPoints:  mp,
+			Name:       aws.String(name),
+			Image:      config.Image,
+			Essential:  config.Essential,
+			Port:       port,
+			Protocol:   protocol,
+			CredsParam: config.CredsParam,
+			Secrets:    config.Secrets,
+			Variables:  config.Variables,
+			Storage: template.SidecarStorageOpts{
+				MountPoints: mp,
+			},
 			DockerLabels: config.DockerLabels,
 			DependsOn:    convertDependsOn(config.DependsOn),
 			EntryPoint:   entrypoint,
@@ -270,6 +273,8 @@ func convertLogging(lc manifest.Logging) *template.LogConfigOpts {
 		EnableMetadata: lc.GetEnableMetadata(),
 		Destination:    lc.Destination,
 		SecretOptions:  lc.SecretOptions,
+		Variables:      lc.Variables,
+		Secrets:        lc.Secrets,
 	}
 }
 
@@ -470,14 +475,14 @@ func convertEFSConfiguration(in manifest.EFSVolumeConfiguration) *template.EFSVo
 	}
 }
 
-func convertNetworkConfig(network manifest.NetworkConfig) *template.NetworkOpts {
+func convertNetworkConfig(network manifest.NetworkConfig) template.NetworkOpts {
 	if network.IsEmpty() {
-		return &template.NetworkOpts{
+		return template.NetworkOpts{
 			AssignPublicIP: template.EnablePublicIP,
 			SubnetsType:    template.PublicSubnetsPlacement,
 		}
 	}
-	opts := &template.NetworkOpts{
+	opts := template.NetworkOpts{
 		AssignPublicIP: template.EnablePublicIP,
 		SubnetsType:    template.PublicSubnetsPlacement,
 		SecurityGroups: network.VPC.SecurityGroups,
@@ -492,6 +497,20 @@ func convertNetworkConfig(network manifest.NetworkConfig) *template.NetworkOpts
 	return opts
 }
 
+func convertRDWSNetworkConfig(network manifest.RequestDrivenWebServiceNetworkConfig) template.NetworkOpts {
+	opts := template.NetworkOpts{}
+	if network.IsEmpty() {
+		return opts
+	}
+	if network.VPC.Placement == nil {
+		return opts
+	}
+	if string(*network.VPC.Placement) == string(manifest.PrivateSubnetPlacement) {
+		opts.SubnetsType = template.PrivateSubnetsPlacement
+	}
+	return opts
+}
+
 func convertAlias(alias manifest.Alias) ([]string, error) {
 	out, err := alias.ToStringSlice()
 	if err != nil {
@@ -640,3 +659,34 @@ func convertAppInformation(app deploy.AppInformation) (delegationRole *string, d
 	}
 	return
 }
+
+func convertPlatform(platform manifest.PlatformArgsOrString) template.RuntimePlatformOpts {
+	if platform.IsEmpty() {
+		return template.RuntimePlatformOpts{}
+	}
+
+	os := template.OSLinux
+	switch platform.OS() {
+	case manifest.OSWindows, manifest.OSWindowsServer2019Core:
+		os = template.OSWindowsServerCore
+	case manifest.OSWindowsServer2019Full:
+		os = template.OSWindowsServerFull
+	}
+
+	arch := template.ArchX86
+	if manifest.IsArmArch(platform.Arch()) {
+		arch = template.ArchARM64
+	}
+	return template.RuntimePlatformOpts{
+		OS:   os,
+		Arch: arch,
+	}
+}
+
+func convertHTTPVersion(protocolVersion *string) *string {
+	if protocolVersion == nil {
+		return nil
+	}
+	pv := strings.ToUpper(*protocolVersion)
+	return &pv
+}
