@@ -74,7 +74,11 @@ func (s *WorkerService) Template() (string, error) {
 	if err != nil {
 		return "", fmt.Errorf("read backlog-per-task-calculator lambda function source code: %w", err)
 	}
-	outputs, err := s.addonsOutputs()
+	addonsParams, err := s.addonsParameters()
+	if err != nil {
+		return "", err
+	}
+	addonsOutputs, err := s.addonsOutputs()
 	if err != nil {
 		return "", err
 	}
@@ -108,10 +112,15 @@ func (s *WorkerService) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
+	publishers, err := convertPublish(s.manifest.Publish(), s.rc.AccountID, s.rc.Region, s.app, s.env, s.name)
+	if err != nil {
+		return "", fmt.Errorf(`convert "publish" field for service %s: %w`, s.name, err)
+	}
 	content, err := s.parser.ParseWorkerService(template.WorkloadOpts{
 		Variables:                      s.manifest.WorkerServiceConfig.Variables,
 		Secrets:                        s.manifest.WorkerServiceConfig.Secrets,
-		NestedStack:                    outputs,
+		NestedStack:                    addonsOutputs,
+		AddonsExtraParams:              addonsParams,
 		Sidecars:                       sidecars,
 		Autoscaling:                    autoscaling,
 		CapacityProviders:              capacityProviders,
@@ -132,6 +141,8 @@ func (s *WorkerService) Template() (string, error) {
 		CredentialsParameter:           aws.StringValue(s.manifest.ImageConfig.Image.Credentials),
 		ServiceDiscoveryEndpoint:       s.rc.ServiceDiscoveryEndpoint,
 		Subscribe:                      subscribe,
+		Publish:                        publishers,
+		Platform:                       convertPlatform(s.manifest.Platform),
 	})
 	if err != nil {
 		return "", fmt.Errorf("parse worker service template: %w", err)
