@@ -61,12 +61,14 @@ const (
 // RuntimeConfig represents configuration that's defined outside of the manifest file
 // that is needed to create a CloudFormation stack.
 type RuntimeConfig struct {
-	Image                    *ECRImage         // Optional. Image location in an ECR repository.
-	AddonsTemplateURL        string            // Optional. S3 object URL for the addons template.
-	AdditionalTags           map[string]string // AdditionalTags are labels applied to resources in the workload stack.
-	ServiceDiscoveryEndpoint string            // Endpoint for the service discovery namespace in the environment.
-	AccountID                string            // Account ID for constructing ARNs
-	Region                   string            // Region for constructing ARNs
+	Image             *ECRImage         // Optional. Image location in an ECR repository.
+	AddonsTemplateURL string            // Optional. S3 object URL for the addons template.
+	AdditionalTags    map[string]string // AdditionalTags are labels applied to resources in the workload stack.
+
+	// The target environment metadata.
+	ServiceDiscoveryEndpoint string // Endpoint for the service discovery namespace in the environment.
+	AccountID                string
+	Region                   string
 }
 
 // ECRImage represents configuration about the pushed ECR image that is needed to
@@ -91,8 +93,9 @@ func (i ECRImage) GetLocation() string {
 	return fmt.Sprintf("%s:%s", i.RepoURL, "latest")
 }
 
-type templater interface {
+type addons interface {
 	Template() (string, error)
+	Parameters() (string, error)
 }
 
 type location interface {
@@ -109,7 +112,7 @@ type wkld struct {
 	image location
 
 	parser template.Parser
-	addons templater
+	addons addons
 }
 
 // StackName returns the name of the stack.
@@ -207,6 +210,18 @@ func (w *wkld) addonsOutputs() (*template.WorkloadNestedStackOpts, error) {
 	}, nil
 }
 
+func (w *wkld) addonsParameters() (string, error) {
+	params, err := w.addons.Parameters()
+	if err != nil {
+		var notFoundErr *addon.ErrAddonsNotFound
+		if !errors.As(err, &notFoundErr) {
+			return "", fmt.Errorf("parse addons parameters for %s: %w", w.name, err)
+		}
+		return "", nil
+	}
+	return params, nil
+}
+
 func securityGroupOutputNames(outputs []addon.Output) []string {
 	var securityGroups []string
 	for _, out := range outputs {
