@@ -13,7 +13,7 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-func TestLoadBalancedWebServiceConfig_Validate(t *testing.T) {
+func TestLoadBalancedWebService_Validate(t *testing.T) {
 	testImageConfig := ImageWithPortAndHealthcheck{
 		ImageWithPort: ImageWithPort{
 			Image: Image{
@@ -76,7 +76,7 @@ func TestLoadBalancedWebServiceConfig_Validate(t *testing.T) {
 					ImageConfig: testImageConfig,
 					Network: NetworkConfig{
 						vpcConfig{
-							SecurityGroups: []string{},
+							Placement: (*Placement)(aws.String("")),
 						},
 					},
 				},
@@ -117,6 +117,34 @@ func TestLoadBalancedWebServiceConfig_Validate(t *testing.T) {
 			},
 			wantedError: fmt.Errorf(`"name" must be specified`),
 		},
+		"error if fail to validate HTTP load balancer target": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{Name: aws.String("mockName")},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					RoutingRule: RoutingRule{
+						TargetContainer: aws.String("foo"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate HTTP load balancer target: `,
+		},
+		"error if fail to validate network load balancer target": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{Name: aws.String("mockName")},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					RoutingRule: RoutingRule{
+						TargetContainer: aws.String("mockName"),
+					},
+					NLBConfig: NetworkLoadBalancerConfiguration{
+						Port:            aws.String("443"),
+						TargetContainer: aws.String("foo"),
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate network load balancer target: `,
+		},
 		"error if fail to validate dependencies": {
 			lbConfig: LoadBalancedWebService{
 				Workload: Workload{Name: aws.String("mockName")},
@@ -136,6 +164,39 @@ func TestLoadBalancedWebServiceConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate container dependencies: `,
 		},
+		"error if fail to validate windows": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{Name: aws.String("mockName")},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform:       PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("windows/amd64"))},
+						ExecuteCommand: ExecuteCommand{Enable: aws.Bool(true)},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate Windows: `,
+		},
+		"error if fail to validate ARM": {
+			lbConfig: LoadBalancedWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				LoadBalancedWebServiceConfig: LoadBalancedWebServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/arm64"))},
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Spot:         aws.Int(123),
+								workloadType: LoadBalancedWebServiceType,
+							},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate ARM: `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -155,7 +216,7 @@ func TestLoadBalancedWebServiceConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestBackendServiceConfig_Validate(t *testing.T) {
+func TestBackendService_Validate(t *testing.T) {
 	testImageConfig := ImageWithHealthcheckAndOptionalPort{
 		ImageWithOptionalPort: ImageWithOptionalPort{
 			Image: Image{
@@ -205,7 +266,7 @@ func TestBackendServiceConfig_Validate(t *testing.T) {
 					ImageConfig: testImageConfig,
 					Network: NetworkConfig{
 						vpcConfig{
-							SecurityGroups: []string{},
+							Placement: (*Placement)(aws.String("")),
 						},
 					},
 				},
@@ -263,6 +324,39 @@ func TestBackendServiceConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate container dependencies: `,
 		},
+		"error if fail to validate Windows": {
+			config: BackendService{
+				Workload: Workload{Name: aws.String("mockName")},
+				BackendServiceConfig: BackendServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform:       PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("windows/amd64"))},
+						ExecuteCommand: ExecuteCommand{Enable: aws.Bool(true)},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate Windows: `,
+		},
+		"error if fail to validate ARM": {
+			config: BackendService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				BackendServiceConfig: BackendServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/arm64"))},
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Spot:         aws.Int(123),
+								workloadType: BackendServiceType,
+							},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate ARM: `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -282,12 +376,12 @@ func TestBackendServiceConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestRequestDrivenWebServiceConfig_Validate(t *testing.T) {
+func TestRequestDrivenWebService_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		config RequestDrivenWebService
 
-		wantedErrorMsgPrefix string
 		wantedError          error
+		wantedErrorMsgPrefix string
 	}{
 		"error if fail to validate image": {
 			config: RequestDrivenWebService{
@@ -305,6 +399,50 @@ func TestRequestDrivenWebServiceConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate "image": `,
 		},
+		"error if fail to validate instance": {
+			config: RequestDrivenWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
+					ImageConfig: ImageWithPort{
+						Image: Image{
+							Build: BuildArgsOrString{BuildString: aws.String("mockBuild")},
+						},
+						Port: uint16P(80),
+					},
+					InstanceConfig: AppRunnerInstanceConfig{
+						CPU:    nil,
+						Memory: nil,
+						Platform: PlatformArgsOrString{
+							PlatformString: (*PlatformString)(aws.String("mockPlatform")),
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "platform": `,
+		},
+		"error if fail to validate network": {
+			config: RequestDrivenWebService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
+					ImageConfig: ImageWithPort{
+						Image: Image{
+							Build: BuildArgsOrString{BuildString: aws.String("mockBuild")},
+						},
+						Port: uint16P(80),
+					},
+					Network: RequestDrivenWebServiceNetworkConfig{
+						VPC: rdwsVpcConfig{
+							Placement: (*RequestDrivenWebServicePlacement)(aws.String("")),
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "network": `,
+		},
 		"error if name is not set": {
 			config: RequestDrivenWebService{
 				RequestDrivenWebServiceConfig: RequestDrivenWebServiceConfig{
@@ -322,7 +460,6 @@ func TestRequestDrivenWebServiceConfig_Validate(t *testing.T) {
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			gotErr := tc.config.Validate()
-
 			if tc.wantedError != nil {
 				require.EqualError(t, gotErr, tc.wantedError.Error())
 				return
@@ -337,7 +474,7 @@ func TestRequestDrivenWebServiceConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestWorkerServiceConfig_Validate(t *testing.T) {
+func TestWorkerService_Validate(t *testing.T) {
 	testImageConfig := ImageWithHealthcheck{
 		Image: Image{
 			Build: BuildArgsOrString{BuildString: aws.String("mockBuild")},
@@ -383,7 +520,7 @@ func TestWorkerServiceConfig_Validate(t *testing.T) {
 					ImageConfig: testImageConfig,
 					Network: NetworkConfig{
 						vpcConfig{
-							SecurityGroups: []string{},
+							Placement: (*Placement)(aws.String("")),
 						},
 					},
 				},
@@ -405,6 +542,19 @@ func TestWorkerServiceConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate "subscribe": `,
 		},
+		"error if fail to validate publish": {
+			config: WorkerService{
+				WorkerServiceConfig: WorkerServiceConfig{
+					ImageConfig: testImageConfig,
+					PublishConfig: PublishConfig{
+						Topics: []Topic{
+							{},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "publish": `,
+		},
 		"error if fail to validate taskdef override": {
 			config: WorkerService{
 				WorkerServiceConfig: WorkerServiceConfig{
@@ -443,6 +593,39 @@ func TestWorkerServiceConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate container dependencies: `,
 		},
+		"error if fail to validate windows": {
+			config: WorkerService{
+				Workload: Workload{Name: aws.String("mockName")},
+				WorkerServiceConfig: WorkerServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform:       PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("windows/amd64"))},
+						ExecuteCommand: ExecuteCommand{Enable: aws.Bool(true)},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate Windows: `,
+		},
+		"error if fail to validate ARM": {
+			config: WorkerService{
+				Workload: Workload{
+					Name: aws.String("mockName"),
+				},
+				WorkerServiceConfig: WorkerServiceConfig{
+					ImageConfig: testImageConfig,
+					TaskConfig: TaskConfig{
+						Platform: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/arm64"))},
+						Count: Count{
+							AdvancedCount: AdvancedCount{
+								Spot:         aws.Int(123),
+								workloadType: WorkerServiceType,
+							},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate ARM: `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -462,7 +645,7 @@ func TestWorkerServiceConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestScheduledJobConfig_Validate(t *testing.T) {
+func TestScheduledJob_Validate(t *testing.T) {
 	testImageConfig := ImageWithHealthcheck{
 		Image: Image{
 			Build: BuildArgsOrString{BuildString: aws.String("mockBuild")},
@@ -508,7 +691,7 @@ func TestScheduledJobConfig_Validate(t *testing.T) {
 					ImageConfig: testImageConfig,
 					Network: NetworkConfig{
 						vpcConfig{
-							SecurityGroups: []string{},
+							Placement: (*Placement)(aws.String("")),
 						},
 					},
 				},
@@ -587,6 +770,22 @@ func TestScheduledJobConfig_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate container dependencies: `,
 		},
+		"error if fail to validate windows": {
+			config: ScheduledJob{
+				Workload: Workload{Name: aws.String("mockName")},
+				ScheduledJobConfig: ScheduledJobConfig{
+					ImageConfig: testImageConfig,
+					On: JobTriggerConfig{
+						Schedule: aws.String("mockSchedule"),
+					},
+					TaskConfig: TaskConfig{
+						Platform:       PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("windows/amd64"))},
+						ExecuteCommand: ExecuteCommand{Enable: aws.Bool(true)},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate Windows: `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -681,6 +880,7 @@ func TestImage_Validate(t *testing.T) {
 		})
 	}
 }
+
 func TestDependsOn_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		in     DependsOn
@@ -705,6 +905,7 @@ func TestDependsOn_Validate(t *testing.T) {
 		})
 	}
 }
+
 func TestRoutingRule_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		RoutingRule RoutingRule
@@ -729,6 +930,17 @@ func TestRoutingRule_Validate(t *testing.T) {
 			},
 			wantedErrorMsgPrefix: `validate "allowed_source_ips[1]": `,
 		},
+		"error if protocol version is not valid": {
+			RoutingRule: RoutingRule{
+				ProtocolVersion: aws.String("quic"),
+			},
+			wantedErrorMsgPrefix: `"version" field value 'quic' must be one of GRPC, HTTP1 or HTTP2`,
+		},
+		"should not error if protocol version is not uppercase": {
+			RoutingRule: RoutingRule{
+				ProtocolVersion: aws.String("gRPC"),
+			},
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -748,6 +960,43 @@ func TestRoutingRule_Validate(t *testing.T) {
 	}
 }
 
+func TestNetworkLoadBalancerConfiguration_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		nlb NetworkLoadBalancerConfiguration
+
+		wantedErrorMsgPrefix string
+		wantedError          error
+	}{
+		"success if empty": {
+			nlb: NetworkLoadBalancerConfiguration{},
+		},
+		"error if port unspecified": {
+			nlb: NetworkLoadBalancerConfiguration{
+				TargetContainer: aws.String("main"),
+			},
+			wantedErrorMsgPrefix: `validate "nlb": `,
+			wantedError:          fmt.Errorf(`"port" must be specified`),
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.nlb.Validate()
+
+			if tc.wantedError != nil {
+				require.EqualError(t, gotErr, tc.wantedError.Error())
+				return
+			}
+			if tc.wantedErrorMsgPrefix != "" {
+				require.Error(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
+				return
+			}
+			require.NoError(t, gotErr)
+		})
+	}
+}
+
 func TestIPNet_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		in     IPNet
@@ -781,7 +1030,7 @@ func TestTaskConfig_Validate(t *testing.T) {
 		"error if fail to validate platform": {
 			TaskConfig: TaskConfig{
 				Platform: PlatformArgsOrString{
-					PlatformString: (*PlatformString)(aws.String("foobar")),
+					PlatformString: (*PlatformString)(aws.String("")),
 				},
 			},
 			wantedErrorPrefix: `validate "platform": `,
@@ -827,52 +1076,65 @@ func TestTaskConfig_Validate(t *testing.T) {
 		})
 	}
 }
-func TestPlatformString_Validate(t *testing.T) {
+
+func TestPlatformArgsOrString_Validate(t *testing.T) {
 	testCases := map[string]struct {
-		in     PlatformString
+		in     PlatformArgsOrString
 		wanted error
 	}{
 		"error if platform string is invalid": {
-			in:     PlatformString("foobar"),
-			wanted: fmt.Errorf("platform foobar is invalid; the valid platform is: linux/amd64"),
+			in:     PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("foobar/amd64"))},
+			wanted: fmt.Errorf("platform 'foobar/amd64' is invalid; valid platforms are: linux/amd64, linux/x86_64, linux/arm, linux/arm64, windows/amd64 and windows/x86_64"),
+		},
+		"error if only half of platform string is specified": {
+			in:     PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux"))},
+			wanted: fmt.Errorf("platform 'linux' must be in the format [OS]/[Arch]"),
 		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			err := tc.in.Validate()
-
-			if tc.wanted != nil {
-				require.EqualError(t, err, tc.wanted.Error())
-			} else {
-				require.NoError(t, err)
-			}
-		})
-	}
-}
-func TestPlatformArgs_Validate(t *testing.T) {
-	testCases := map[string]struct {
-		in     PlatformArgs
-		wanted error
-	}{
 		"error if only osfamily is specified": {
-			in: PlatformArgs{
-				OSFamily: aws.String("linux"),
+			in: PlatformArgsOrString{
+				PlatformArgs: PlatformArgs{
+					OSFamily: aws.String("linux"),
+				},
+			},
+			wanted: fmt.Errorf(`fields "osfamily" and "architecture" must either both be specified or both be empty`),
+		},
+		"error if only architecture is specified": {
+			in: PlatformArgsOrString{
+				PlatformArgs: PlatformArgs{
+					Arch: aws.String("X86_64"),
+				},
 			},
 			wanted: fmt.Errorf(`fields "osfamily" and "architecture" must either both be specified or both be empty`),
 		},
 		"error if osfamily is invalid": {
-			in: PlatformArgs{
-				OSFamily: aws.String("foo"),
-				Arch:     aws.String("amd64"),
+			in: PlatformArgsOrString{
+				PlatformArgs: PlatformArgs{
+					OSFamily: aws.String("foo"),
+					Arch:     aws.String("amd64"),
+				},
 			},
-			wanted: fmt.Errorf("OS foo is invalid; the valid operating system is: linux"),
+			wanted: fmt.Errorf("platform pair ('foo', 'amd64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
 		},
 		"error if arch is invalid": {
-			in: PlatformArgs{
-				OSFamily: aws.String("linux"),
-				Arch:     aws.String("bar"),
+			in: PlatformArgsOrString{
+				PlatformArgs: PlatformArgs{
+					OSFamily: aws.String("linux"),
+					Arch:     aws.String("bar"),
+				},
 			},
-			wanted: fmt.Errorf("architecture bar is invalid; the valid architecture is: amd64"),
+			wanted: fmt.Errorf("platform pair ('linux', 'bar') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
+		},
+		"return nil if platform string valid": {
+			in: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/amd64"))},
+		},
+		"return nil if platform args valid": {
+			in: PlatformArgsOrString{
+				PlatformArgs: PlatformArgs{
+					OSFamily: aws.String("linux"),
+					Arch:     aws.String("amd64"),
+				},
+			},
+			wanted: nil,
 		},
 	}
 	for name, tc := range testCases {
@@ -887,6 +1149,7 @@ func TestPlatformArgs_Validate(t *testing.T) {
 		})
 	}
 }
+
 func TestAdvancedCount_Validate(t *testing.T) {
 	var (
 		mockPerc    = Percentage(70)
@@ -1462,7 +1725,7 @@ func TestNetworkConfig_Validate(t *testing.T) {
 		"error if fail to validate vpc": {
 			config: NetworkConfig{
 				VPC: vpcConfig{
-					SecurityGroups: []string{},
+					Placement: (*Placement)(aws.String("")),
 				},
 			},
 			wantedErrorPrefix: `validate "vpc": `,
@@ -1481,6 +1744,60 @@ func TestNetworkConfig_Validate(t *testing.T) {
 	}
 }
 
+func TestRequestDrivenWebServiceNetworkConfig_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		config RequestDrivenWebServiceNetworkConfig
+
+		wantedErrorPrefix string
+	}{
+		"error if fail to validate vpc": {
+			config: RequestDrivenWebServiceNetworkConfig{
+				VPC: rdwsVpcConfig{
+					Placement: (*RequestDrivenWebServicePlacement)(aws.String("")),
+				},
+			},
+			wantedErrorPrefix: `validate "vpc": `,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.config.Validate()
+
+			if tc.wantedErrorPrefix != "" {
+				require.Contains(t, gotErr.Error(), tc.wantedErrorPrefix)
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
+func TestRdwsVpcConfig_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		config rdwsVpcConfig
+
+		wantedErrorPrefix string
+	}{
+		"error if fail to validate placement": {
+			config: rdwsVpcConfig{
+				Placement: (*RequestDrivenWebServicePlacement)(aws.String("")),
+			},
+			wantedErrorPrefix: `validate "placement": `,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.config.Validate()
+
+			if tc.wantedErrorPrefix != "" {
+				require.Contains(t, gotErr.Error(), tc.wantedErrorPrefix)
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
 func TestVpcConfig_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		config vpcConfig
@@ -1489,7 +1806,7 @@ func TestVpcConfig_Validate(t *testing.T) {
 	}{
 		"error if fail to validate placement": {
 			config: vpcConfig{
-				SecurityGroups: []string{},
+				Placement: (*Placement)(aws.String("")),
 			},
 			wantedErrorPrefix: `validate "placement": `,
 		},
@@ -1508,12 +1825,14 @@ func TestVpcConfig_Validate(t *testing.T) {
 }
 
 func TestPlacement_Validate(t *testing.T) {
+	mockEmptyPlacement := Placement("")
 	mockInvalidPlacement := Placement("external")
 	testCases := map[string]struct {
 		in     *Placement
 		wanted error
 	}{
 		"should return an error if placement is empty": {
+			in:     &mockEmptyPlacement,
 			wanted: errors.New(`"placement" cannot be empty`),
 		},
 		"should return an error if placement is invalid": {
@@ -1534,6 +1853,99 @@ func TestPlacement_Validate(t *testing.T) {
 	}
 }
 
+func TestRequestDrivenWebServicePlacement_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		in     *RequestDrivenWebServicePlacement
+		wanted error
+	}{
+		"should return an error if placement is public": {
+			in:     (*RequestDrivenWebServicePlacement)(aws.String("public")),
+			wanted: errors.New(`placement "public" is not supported for Request-Driven Web Service`),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			err := tc.in.Validate()
+
+			if tc.wanted != nil {
+				require.EqualError(t, err, tc.wanted.Error())
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
+
+func TestAppRunnerInstanceConfig_Validate(t *testing.T) {
+	testCases := map[string]struct {
+		config            AppRunnerInstanceConfig
+		wantedErrorPrefix string
+		wantedError       error
+	}{
+		"error if fail to validate platforms": {
+			config: AppRunnerInstanceConfig{
+				Platform: PlatformArgsOrString{
+					PlatformString: (*PlatformString)(aws.String("")),
+				},
+			},
+			wantedErrorPrefix: `validate "platform": `,
+		},
+		"error if windows os in PlatformString": {
+			config: AppRunnerInstanceConfig{
+				Platform: PlatformArgsOrString{
+					PlatformString: (*PlatformString)(aws.String("windows/amd64")),
+				},
+			},
+			wantedError: fmt.Errorf("Windows is not supported for App Runner services"),
+		},
+		"error if windows os in PlatformArgs": {
+			config: AppRunnerInstanceConfig{
+				CPU:    nil,
+				Memory: nil,
+				Platform: PlatformArgsOrString{
+					PlatformArgs: PlatformArgs{
+						OSFamily: aws.String("windows"),
+						Arch:     aws.String("amd64"),
+					},
+				},
+			},
+			wantedError: fmt.Errorf("Windows is not supported for App Runner services"),
+		},
+		"error if invalid arch in PlatformString": {
+			config: AppRunnerInstanceConfig{
+				Platform: PlatformArgsOrString{
+					PlatformArgs: PlatformArgs{
+						OSFamily: aws.String("linux"),
+						Arch:     aws.String("leg64"),
+					},
+				},
+			},
+			wantedError: fmt.Errorf("validate \"platform\": platform pair ('linux', 'leg64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
+		},
+		"error if App Runner + ARM": {
+			config: AppRunnerInstanceConfig{
+				Platform: PlatformArgsOrString{
+					PlatformString: (*PlatformString)(aws.String("linux/arm64")),
+				},
+			},
+			wantedError: fmt.Errorf("App Runner services can only build on amd64 and x86_64 architectures"),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.config.Validate()
+
+			if tc.wantedErrorPrefix != "" {
+				require.Contains(t, gotErr.Error(), tc.wantedErrorPrefix)
+			} else if tc.wantedError != nil {
+				require.EqualError(t, gotErr, tc.wantedError.Error())
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
 func TestJobTriggerConfig_Validate(t *testing.T) {
 	testCases := map[string]struct {
 		in     *JobTriggerConfig
@@ -1705,6 +2117,62 @@ func TestOverrideRule_Validate(t *testing.T) {
 	}
 }
 
+func TestValidateLoadBalancerTarget(t *testing.T) {
+	testCases := map[string]struct {
+		in     validateTargetContainerOpts
+		wanted error
+	}{
+		"should return an error if target container doesn't exist": {
+			in: validateTargetContainerOpts{
+				mainContainerName: "mockMainContainer",
+				targetContainer:   aws.String("foo"),
+			},
+			wanted: fmt.Errorf("target container foo doesn't exist"),
+		},
+		"should return an error if target container doesn't expose any port": {
+			in: validateTargetContainerOpts{
+				mainContainerName: "mockMainContainer",
+				targetContainer:   aws.String("foo"),
+				sidecarConfig: map[string]*SidecarConfig{
+					"foo": {},
+				},
+			},
+			wanted: fmt.Errorf("target container foo doesn't expose any port"),
+		},
+		"success with no target container set": {
+			in: validateTargetContainerOpts{
+				mainContainerName: "mockMainContainer",
+				targetContainer:   nil,
+				sidecarConfig: map[string]*SidecarConfig{
+					"foo": {},
+				},
+			},
+		},
+		"success": {
+			in: validateTargetContainerOpts{
+				mainContainerName: "mockMainContainer",
+				targetContainer:   aws.String("foo"),
+				sidecarConfig: map[string]*SidecarConfig{
+					"foo": {
+						Port: aws.String("80"),
+					},
+				},
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			err := validateTargetContainer(tc.in)
+
+			if tc.wanted != nil {
+				require.EqualError(t, err, tc.wanted.Error())
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
+
 func TestValidateContainerDeps(t *testing.T) {
 	testCases := map[string]struct {
 		in     validateDependenciesOpts
@@ -1745,6 +2213,17 @@ func TestValidateContainerDeps(t *testing.T) {
 			},
 			wanted: fmt.Errorf("container foo does not exist"),
 		},
+		"should return an error if a firelens container does not exist": {
+			in: validateDependenciesOpts{
+				mainContainerName: "mockMainContainer",
+				imageConfig: Image{
+					DependsOn: DependsOn{
+						"firelens_log_router": "start",
+					},
+				},
+			},
+			wanted: fmt.Errorf("container firelens_log_router does not exist"),
+		},
 		"should return an error if a sidecar container dependency does not exist": {
 			in: validateDependenciesOpts{
 				mainContainerName: "mockMainContainer",
@@ -1797,6 +2276,28 @@ func TestValidateContainerDeps(t *testing.T) {
 			},
 			wanted: fmt.Errorf("circular container dependency chain includes the following containers: [alpha beta gamma]"),
 		},
+		"success": {
+			in: validateDependenciesOpts{
+				mainContainerName: "alpha",
+				imageConfig: Image{
+					DependsOn: DependsOn{
+						"firelens_log_router": "start",
+						"beta":                "complete",
+					},
+				},
+				logging: Logging{
+					Image: aws.String("foobar"),
+				},
+				sidecarConfig: map[string]*SidecarConfig{
+					"beta": {
+						Essential: aws.Bool(false),
+						DependsOn: DependsOn{
+							"firelens_log_router": "start",
+						},
+					},
+				},
+			},
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -1810,3 +2311,86 @@ func TestValidateContainerDeps(t *testing.T) {
 		})
 	}
 }
+
+func TestValidateWindows(t *testing.T) {
+	testCases := map[string]struct {
+		in          validateWindowsOpts
+		wantedError error
+	}{
+		"should return an error if efs specified": {
+			in: validateWindowsOpts{
+				execEnabled: true,
+			},
+			wantedError: fmt.Errorf(`'exec' is not supported when deploying a Windows container`),
+		},
+		"error if efs specified": {
+			in: validateWindowsOpts{
+				efsVolumes: map[string]*Volume{
+					"someVolume": {
+						EFS: EFSConfigOrBool{
+							Enabled: aws.Bool(true),
+						},
+						MountPointOpts: MountPointOpts{
+							ContainerPath: aws.String("mockPath"),
+						},
+					},
+				},
+			},
+			wantedError: errors.New(`'EFS' is not supported when deploying a Windows container`),
+		},
+		"should return nil if neither efs nor exec specified": {
+			in: validateWindowsOpts{
+				execEnabled: false,
+			},
+			wantedError: nil,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			err := validateWindows(tc.in)
+
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
+
+func TestValidateARM(t *testing.T) {
+	testCases := map[string]struct {
+		in          validateARMOpts
+		wantedError error
+	}{
+		"should return an error if Spot specified inline": {
+			in: validateARMOpts{
+				Spot: aws.Int(2),
+			},
+			wantedError: fmt.Errorf(`'Fargate Spot' is not supported when deploying on ARM architecture`),
+		},
+		"should return an error if Spot specified with spot_from": {
+			in: validateARMOpts{
+				SpotFrom: aws.Int(2),
+			},
+			wantedError: fmt.Errorf(`'Fargate Spot' is not supported when deploying on ARM architecture`),
+		},
+		"should return nil if Spot not specified": {
+			in: validateARMOpts{
+				Spot: nil,
+			},
+			wantedError: nil,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			err := validateARM(tc.in)
+
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
