@@ -1,3 +1,4 @@
+//go:build integration
 // +build integration
 
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
@@ -21,13 +22,22 @@ func TestTemplate_ParseScheduledJob(t *testing.T) {
 	}{
 		"renders a valid template by default": {
 			opts: template.WorkloadOpts{
-				ServiceDiscoveryEndpoint: "test.app.local"},
+				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+			},
 		},
 		"renders with timeout and no retries": {
 			opts: template.WorkloadOpts{
 				StateMachine: &template.StateMachineOpts{
 					Timeout: aws.Int(3600),
 				},
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
@@ -37,6 +47,10 @@ func TestTemplate_ParseScheduledJob(t *testing.T) {
 					Retries: aws.Int(5),
 					Timeout: aws.Int(3600),
 				},
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
@@ -51,6 +65,10 @@ func TestTemplate_ParseScheduledJob(t *testing.T) {
 					SecretOutputs:   []string{"TablePassword"},
 					PolicyOutputs:   []string{"TablePolicy"},
 				},
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
@@ -87,6 +105,21 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 			opts: template.WorkloadOpts{
 				HTTPHealthCheck:          defaultHttpHealthCheck,
 				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+			},
+		},
+		"renders a valid grpc template by default": {
+			opts: template.WorkloadOpts{
+				HTTPVersion:              aws.String("GRPC"),
+				HTTPHealthCheck:          defaultHttpHealthCheck,
+				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 			},
 		},
 		"renders a valid template with addons with no outputs": {
@@ -95,6 +128,10 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 				NestedStack: &template.WorkloadNestedStackOpts{
 					StackName: "AddonsStack",
 				},
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
@@ -107,15 +144,19 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 					SecretOutputs:   []string{"TablePassword"},
 					PolicyOutputs:   []string{"TablePolicy"},
 				},
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
 		},
 		"renders a valid template with private subnet placement": {
 			opts: template.WorkloadOpts{
 				HTTPHealthCheck: defaultHttpHealthCheck,
-				Network: &template.NetworkOpts{
-					AssignPublicIP: "DISABLED",
-					SubnetsType:    "PrivateSubnets",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.DisablePublicIP,
+					SubnetsType:    template.PrivateSubnetsPlacement,
 				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 			},
@@ -124,6 +165,10 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 			opts: template.WorkloadOpts{
 				HTTPHealthCheck:          defaultHttpHealthCheck,
 				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				Storage: &template.StorageOpts{
 					Ephemeral: aws.Int(500),
 					EFSPerms: []*template.EFSPermission{
@@ -158,6 +203,10 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 			opts: template.WorkloadOpts{
 				HTTPHealthCheck:          defaultHttpHealthCheck,
 				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				Storage: &template.StorageOpts{
 					EFSPerms: []*template.EFSPermission{
 						{
@@ -185,7 +234,11 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 		},
 		"renders a valid template with ephemeral storage": {
 			opts: template.WorkloadOpts{
-				HTTPHealthCheck:          defaultHttpHealthCheck,
+				HTTPHealthCheck: defaultHttpHealthCheck,
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
 				ServiceDiscoveryEndpoint: "test.app.local",
 				Storage: &template.StorageOpts{
 					Ephemeral: aws.Int(500),
@@ -198,6 +251,24 @@ func TestTemplate_ParseLoadBalancedWebService(t *testing.T) {
 				EntryPoint:               []string{"/bin/echo", "hello"},
 				Command:                  []string{"world"},
 				ServiceDiscoveryEndpoint: "test.app.local",
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+			},
+		},
+		"renders a valida template with additional addons parameters": {
+			opts: template.WorkloadOpts{
+				ServiceDiscoveryEndpoint: "test.app.local",
+				HTTPHealthCheck:          defaultHttpHealthCheck,
+				Network: template.NetworkOpts{
+					AssignPublicIP: template.EnablePublicIP,
+					SubnetsType:    template.PublicSubnetsPlacement,
+				},
+				AddonsExtraParams: `ServiceName: !Ref Service
+DiscoveryServiceArn:
+  Fn::GetAtt: [DiscoveryService, Arn]
+`,
 			},
 		},
 	}
