@@ -40,6 +40,15 @@ const (
 	DisablePublicIP         = "DISABLED"
 	PublicSubnetsPlacement  = "PublicSubnets"
 	PrivateSubnetsPlacement = "PrivateSubnets"
+
+	// RuntimePlatform configuration.
+	OSLinux             = "LINUX"
+	OSWindowsServerFull = "WINDOWS_SERVER_2019_FULL"
+	OSWindowsServerCore = "WINDOWS_SERVER_2019_CORE"
+
+	ArchX86   = "X86_64"
+	ArchARM   = "ARM"
+	ArchARM64 = "ARM64"
 )
 
 // Constants for ARN options.
@@ -51,7 +60,8 @@ var (
 	// Template names under "workloads/partials/cf/".
 	partialsWorkloadCFTemplateNames = []string{
 		"loggroup",
-		"envvars",
+		"envvars-container",
+		"envvars-common",
 		"secrets",
 		"executionrole",
 		"taskrole",
@@ -75,6 +85,13 @@ var (
 		"accessrole",
 		"publish",
 		"subscribe",
+		"nlb",
+		"vpc-connector",
+	}
+
+	// Operating systems to determine Fargate platform versions.
+	osFamiliesForPV100 = []string{
+		OSWindowsServerFull, OSWindowsServerCore,
 	}
 )
 
@@ -98,7 +115,7 @@ type SidecarOpts struct {
 	CredsParam   *string
 	Variables    map[string]string
 	Secrets      map[string]string
-	MountPoints  []*MountPoint
+	Storage      SidecarStorageOpts
 	DockerLabels map[string]string
 	DependsOn    map[string]string
 	EntryPoint   []string
@@ -106,6 +123,11 @@ type SidecarOpts struct {
 	HealthCheck  *ContainerHealthCheck
 }
 
+// SidecarStorageOpts holds data structures for rendering Mount Points inside of a sidecar.
+type SidecarStorageOpts struct {
+	MountPoints []*MountPoint
+}
+
 // StorageOpts holds data structures for rendering Volumes and Mount Points
 type StorageOpts struct {
 	Ephemeral         *int
@@ -168,6 +190,8 @@ type LogConfigOpts struct {
 	EnableMetadata *string
 	SecretOptions  map[string]string
 	ConfigFile     *string
+	Variables      map[string]string
+	Secrets        map[string]string
 }
 
 // HTTPHealthCheckOpts holds configuration that's needed for HTTP Health Check.
@@ -182,6 +206,21 @@ type HTTPHealthCheckOpts struct {
 	GracePeriod         *int64
 }
 
+// NetworkLoadBalancerListener holds configuration that's need for a Network Load Balancer listener.
+type NetworkLoadBalancerListener struct {
+	Port            string
+	Protocol        string
+	TargetContainer string
+	TargetPort      string
+	SSLPolicy       *string
+}
+
+// NetworkLoadBalancer holds configuration that's needed for a Network Load Balancer.
+type NetworkLoadBalancer struct {
+	PublicSubnetCIDRs []string
+	Listener          NetworkLoadBalancerListener
+}
+
 // AdvancedCount holds configuration for autoscaling and capacity provider
 // parameters.
 type AdvancedCount struct {
@@ -292,11 +331,35 @@ type NetworkOpts struct {
 	SecurityGroups []string
 }
 
-func defaultNetworkOpts() *NetworkOpts {
-	return &NetworkOpts{
-		AssignPublicIP: EnablePublicIP,
-		SubnetsType:    PublicSubnetsPlacement,
+// RuntimePlatformOpts holds configuration needed for Platform configuration.
+type RuntimePlatformOpts struct {
+	OS   string
+	Arch string
+}
+
+// IsDefault returns true if the platform matches the default docker image platform of "linux/amd64".
+func (p RuntimePlatformOpts) IsDefault() bool {
+	if p.isEmpty() {
+		return true
 	}
+	if p.OS == OSLinux && p.Arch == ArchX86 {
+		return true
+	}
+	return false
+}
+
+// Version returns the Fargate platform version based on the selected os family.
+func (p RuntimePlatformOpts) Version() string {
+	for _, os := range osFamiliesForPV100 {
+		if p.OS == os {
+			return "1.0.0"
+		}
+	}
+	return "LATEST"
+}
+
+func (p RuntimePlatformOpts) isEmpty() bool {
+	return p.OS == "" && p.Arch == ""
 }
 
 // WorkloadOpts holds optional data that can be provided to enable features in a workload stack template.
@@ -307,14 +370,16 @@ type WorkloadOpts struct {
 	Aliases                  []string
 	Tags                     map[string]string        // Used by App Runner workloads to tag App Runner service resources
 	NestedStack              *WorkloadNestedStackOpts // Outputs from nested stacks such as the addons stack.
+	AddonsExtraParams        string                   // Additional user defined Parameters for the addons stack.
 	Sidecars                 []*SidecarOpts
 	LogConfig                *LogConfigOpts
 	Autoscaling              *AutoscalingOpts
 	CapacityProviders        []*CapacityProviderStrategy
 	DesiredCountOnSpot       *int
 	Storage                  *StorageOpts
-	Network                  *NetworkOpts
+	Network                  NetworkOpts
 	ExecuteCommand           *ExecuteCommandOpts
+	Platform                 RuntimePlatformOpts
 	EntryPoint               []string
 	Command                  []string
 	DomainAlias              string
@@ -322,6 +387,7 @@ type WorkloadOpts struct {
 	DependsOn                map[string]string
 	Publish                  *PublishOpts
 	ServiceDiscoveryEndpoint string
+	HTTPVersion              *string
 
 	// Additional options for service templates.
 	WorkloadType        string
@@ -329,6 +395,7 @@ type WorkloadOpts struct {
 	HTTPHealthCheck     HTTPHealthCheckOpts
 	DeregistrationDelay *int64
 	AllowedSourceIps    []string
+	NLB                 *NetworkLoadBalancer
 
 	// Lambda functions.
 	RulePriorityLambda             string
@@ -341,20 +408,9 @@ type WorkloadOpts struct {
 	ScheduleExpression string
 	StateMachine       *StateMachineOpts
 
-	// Additional options for worker service templates.
-	Subscribe *SubscribeOpts
-}
-
-// ParseRequestDrivenWebServiceInput holds data that can be provided to enable features for a request-driven web service stack.
-type ParseRequestDrivenWebServiceInput struct {
-	Variables           map[string]string
-	StartCommand        *string
-	Tags                map[string]string        // Used by App Runner workloads to tag App Runner service resources
-	NestedStack         *WorkloadNestedStackOpts // Outputs from nested stacks such as the addons stack.
-	EnableHealthCheck   bool
-	EnvControllerLambda string
-	Publish             *PublishOpts
-
+	// Additional options for request driven web service templates.
+	StartCommand      *string
+	EnableHealthCheck bool
 	// Input needed for the custom resource that adds a custom domain to the service.
 	Alias                *string
 	ScriptBucketName     *string
@@ -362,44 +418,38 @@ type ParseRequestDrivenWebServiceInput struct {
 	AWSSDKLayer          *string
 	AppDNSDelegationRole *string
 	AppDNSName           *string
+
+	// Additional options for worker service templates.
+	Subscribe *SubscribeOpts
+
+	// List of features to enable for testing that are not yet released.
+	FeatureFlags []string
 }
 
 // ParseLoadBalancedWebService parses a load balanced web service's CloudFormation template
 // with the specified data object and returns its content.
 func (t *Template) ParseLoadBalancedWebService(data WorkloadOpts) (*Content, error) {
-	if data.Network == nil {
-		data.Network = defaultNetworkOpts()
-	}
 	return t.parseSvc(lbWebSvcTplName, data, withSvcParsingFuncs())
 }
 
 // ParseRequestDrivenWebService parses a request-driven web service's CloudFormation template
 // with the specified data object and returns its content.
-func (t *Template) ParseRequestDrivenWebService(data ParseRequestDrivenWebServiceInput) (*Content, error) {
+func (t *Template) ParseRequestDrivenWebService(data WorkloadOpts) (*Content, error) {
 	return t.parseSvc(rdWebSvcTplName, data, withSvcParsingFuncs())
 }
 
 // ParseBackendService parses a backend service's CloudFormation template with the specified data object and returns its content.
 func (t *Template) ParseBackendService(data WorkloadOpts) (*Content, error) {
-	if data.Network == nil {
-		data.Network = defaultNetworkOpts()
-	}
 	return t.parseSvc(backendSvcTplName, data, withSvcParsingFuncs())
 }
 
 // ParseWorkerService parses a worker service's CloudFormation template with the specified data object and returns its content.
 func (t *Template) ParseWorkerService(data WorkloadOpts) (*Content, error) {
-	if data.Network == nil {
-		data.Network = defaultNetworkOpts()
-	}
 	return t.parseSvc(workerSvcTplName, data, withSvcParsingFuncs())
 }
 
 // ParseScheduledJob parses a scheduled job's Cloudformation Template
 func (t *Template) ParseScheduledJob(data WorkloadOpts) (*Content, error) {
-	if data.Network == nil {
-		data.Network = defaultNetworkOpts()
-	}
 	return t.parseJob(scheduledJobTplName, data, withSvcParsingFuncs())
 }
 
@@ -450,6 +500,7 @@ func withSvcParsingFuncs() ParseOption {
 			"logicalIDSafe":       StripNonAlphaNumFunc,
 			"wordSeries":          english.WordSeries,
 			"pluralWord":          english.PluralWord,
+			"contains":            contains,
 		})
 	}
 }
@@ -479,7 +530,7 @@ func envControllerParameters(o WorkloadOpts) []string {
 		parameters = append(parameters, []string{"ALBWorkloads,", "Aliases,"}...) // YAML needs the comma separator; resolved in EnvContr.
 	}
 	if o.Network.SubnetsType == PrivateSubnetsPlacement {
-		parameters = append(parameters, "NATWorkloads,") // YAML needs the comma separator; resolved in EnvContr.
+		parameters = append(parameters, "NATWorkloads,")
 	}
 	if o.Storage != nil && o.Storage.requiresEFSCreation() {
 		parameters = append(parameters, "EFSWorkloads,")
@@ -487,6 +538,15 @@ func envControllerParameters(o WorkloadOpts) []string {
 	return parameters
 }
 
+func contains(list []string, s string) bool {
+	for _, item := range list {
+		if item == s {
+			return true
+		}
+	}
+	return false
+}
+
 // ARN determines the arn for a topic using the SNSTopic name and account information
 func (t Topic) ARN() string {
 	return fmt.Sprintf(snsARNPattern, t.Partition, t.Region, t.AccountID, t.App, t.Env, t.Svc, aws.StringValue(t.Name))
