@@ -497,7 +497,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 	}{
 		"with no workspace services and no store services": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{}, nil).Times(1)
 				m.workloadLister.EXPECT().Summary().Return(
 					&workspace.Summary{
@@ -512,7 +512,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with one workspace service but no store services": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 					}, nil).
@@ -528,7 +528,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with one store service but no workspace services": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{}, nil).
 					Times(1)
 				m.workloadLister.EXPECT().Summary().Return(
@@ -548,7 +548,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with only one service in both workspace and store (skips prompting)": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 					}, nil).Times(1)
@@ -572,7 +572,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with multiple workspace services but only one store service (skips prompting)": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 						"service2",
@@ -598,7 +598,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with multiple store services but only one workspace service (skips prompting)": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{
 						"service3",
 					}, nil).Times(1)
@@ -633,7 +633,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		"with multiple workspace services and multiple store services, of which multiple overlap": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().ServiceNames().Return(
+					EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 						"service2",
@@ -675,7 +675,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		"with error retrieving services from workspace": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().ServiceNames().Return(
+					EXPECT().ListServices().Return(
 					[]string{""}, errors.New("some error"))
 				m.workloadLister.EXPECT().Summary().Return(
 					&workspace.Summary{
@@ -686,7 +686,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		},
 		"with error retrieving services from store": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().ServiceNames().Return(
+				m.workloadLister.EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 						"service2",
@@ -704,7 +704,7 @@ func TestWorkspaceSelect_Service(t *testing.T) {
 		"with error selecting services": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().ServiceNames().Return(
+					EXPECT().ListServices().Return(
 					[]string{
 						"service1",
 						"service2",
@@ -778,7 +778,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		"with no workspace jobs and no store jobs": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().JobNames().Return(
+					EXPECT().ListJobs().Return(
 					[]string{}, nil).Times(1)
 				m.workloadLister.EXPECT().Summary().Return(
 					&workspace.Summary{
@@ -796,7 +796,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		"with one workspace job but no store jobs": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().JobNames().Return(
+					EXPECT().ListJobs().Return(
 					[]string{
 						"job1",
 					}, nil).Times(1)
@@ -816,7 +816,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		"with one store job but no workspace jobs": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().JobNames().Return(
+					EXPECT().ListJobs().Return(
 					[]string{}, nil).Times(1)
 				m.workloadLister.EXPECT().Summary().Return(
 					&workspace.Summary{
@@ -841,7 +841,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 			setupMocks: func(m workspaceSelectMocks) {
 
 				m.workloadLister.
-					EXPECT().JobNames().Return(
+					EXPECT().ListJobs().Return(
 					[]string{
 						"resizer",
 					}, nil).Times(1)
@@ -866,7 +866,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		},
 		"with multiple workspace jobs but only one store job (skips prompting)": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().JobNames().Return(
+				m.workloadLister.EXPECT().ListJobs().Return(
 					[]string{
 						"job1",
 						"job2",
@@ -892,7 +892,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		},
 		"with multiple store jobs but only one workspace job (skips prompting)": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().JobNames().Return(
+				m.workloadLister.EXPECT().ListJobs().Return(
 					[]string{
 						"job3",
 					}, nil).Times(1)
@@ -926,7 +926,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		},
 		"with multiple workspace jobs and multiple store jobs, of which multiple overlap": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().JobNames().Return(
+				m.workloadLister.EXPECT().ListJobs().Return(
 					[]string{
 						"job1",
 						"job2",
@@ -972,7 +972,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		"with error retrieving jobs from workspace": {
 			setupMocks: func(m workspaceSelectMocks) {
 				m.workloadLister.
-					EXPECT().JobNames().Return(
+					EXPECT().ListJobs().Return(
 					[]string{""}, errors.New("some error"))
 				m.workloadLister.EXPECT().Summary().Return(
 					&workspace.Summary{
@@ -983,7 +983,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		},
 		"with error retrieving jobs from store": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().JobNames().Return(
+				m.workloadLister.EXPECT().ListJobs().Return(
 					[]string{
 						"service1",
 						"service2",
@@ -1000,7 +1000,7 @@ func TestWorkspaceSelect_Job(t *testing.T) {
 		},
 		"with error selecting jobs": {
 			setupMocks: func(m workspaceSelectMocks) {
-				m.workloadLister.EXPECT().JobNames().Return(
+				m.workloadLister.EXPECT().ListJobs().Return(
 					[]string{
 						"resizer1",
 						"resizer2",
@@ -2009,7 +2009,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Daily", nil),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Daily", nil),
 				)
 			},
 			wantedSchedule: "@daily",
@@ -2018,7 +2018,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("", errors.New("some error")),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("", errors.New("some error")),
 				)
 			},
 			wantedErr: errors.New("get preset schedule: some error"),
@@ -2027,7 +2027,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
 					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("0 * * * *", nil),
 					m.EXPECT().Confirm(humanReadableCronConfirmPrompt, humanReadableCronConfirmHelp).Return(true, nil),
 				)
@@ -2038,7 +2038,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
 					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("", errors.New("some error")),
 				)
 			},
@@ -2048,7 +2048,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
 					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("0 * * * *", nil),
 					m.EXPECT().Confirm(humanReadableCronConfirmPrompt, humanReadableCronConfirmHelp).Return(false, errors.New("some error")),
 				)
@@ -2059,7 +2059,7 @@ func TestWorkspaceSelect_Schedule(t *testing.T) {
 			mockPrompt: func(m *mocks.MockPrompter) {
 				gomock.InOrder(
 					m.EXPECT().SelectOne(scheduleTypePrompt, scheduleTypeHelp, scheduleTypes, gomock.Any()).Return(fixedSchedule, nil),
-					m.EXPECT().SelectOne(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
+					m.EXPECT().SelectOption(schedulePrompt, scheduleHelp, presetSchedules, gomock.Any()).Return("Custom", nil),
 					m.EXPECT().Get(customSchedulePrompt, customScheduleHelp, gomock.Any(), gomock.Any()).Return("@hourly", nil),
 				)
 			},
